function MCdistance (sigma, T, M)
% La fonction 'MCdistance' évalue la distance moyenne parcourue à vol
% d'oiseau au terme du temps 'T'. 'C' est la matrice de covariance par
% unité de temps du bruit gaussien, et 'M' le nombre de simulations de
% Monte-Carlo demandées.

% On calcule la matrice de Cholesky de C une fois pour toutes, qu'on
% appelle 'R'.
% R = chol(C);

% Il s'agit d'un code extrêmement classique, que je ne commente donc guère.
S = 0;
S2 = 0;
for j = 1:M
    % La simulation de la distance à vol d'oiseau est donnée par la
    % sous-routine 'simulation_prMC' codée plus loin.
    distance = simulation_prMC(sigma,T);
    S = S + distance;
    S2 = S2 + distance * distance;
end

m = S / M;
v = S2 / M - m * m;
fprintf('Distance à vol d''oiseau moyenne : %.4f ± %.4f\n', ...
    m, 1.96*sqrt(v/M));
return


% Sous-routine 'simulation_prMC'
    function distance = simulation_prMC (sigma, T)
        % La fonction 'simulation_prMC' effectue le même travail que
        % 'simulation', à ceci près qu'au lieu de plotter la trajectoire de
        % X à la fin de la simulation, elle retourne la distance 'distance'
        % parcourue à vol d'oiseau. En outre, pour améliorer l'efficacité
        % lors de la boucle de Monte-Carlo, ce n'est pas la matrice C que
        % la fonction 'simulation_prMC' prend comme argument, mais
        % directement sa matrice de Cholesky 'R'.
        N = 1600;
        dt = T / N;
        X = zeros(2,N+1);
        Y = zeros(2,N+1);
        X(:,1) = [0;0];
        Y(:,1) = [0;0];
        for i = 1:N
            X(:,i+1) = X(:,i) + Y(:,i) * dt;
            Y(:,i+1) = Y(:,i) + sigma * randn(2,1) * sqrt(dt);
        end
        % On calcule 'distance', qui est la norme euclidienne de X(:,N+1) -
        % X(:,1). Noter qu'on aurait aussi pu calculer cette norme en
        % utilisant la fonction 'norm' pré-programmée dans Matlab.
        distance = sqrt (sum ((X(:,N+1)-X(:,1)).^2));
        return
    end

end